# Copyright (c)  nexB Inc. and others. All rights reserved.
# http://nexb.com and https://github.com/nexB/vulnerablecode/
# The VulnerableCode software is licensed under the Apache License version 2.0.
# Data generated with VulnerableCode require an acknowledgment.
#
# You may not use this software except in compliance with the License.
# You may obtain a copy of the License at: http://apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software distributed
# under the License is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES OR
# CONDITIONS OF ANY KIND, either express or implied. See the License for the
# specific language governing permissions and limitations under the License.
#
# When you publish or redistribute any data created with VulnerableCode or any VulnerableCode
# derivative work, you must accompany this data with the following acknowledgment:
#
#  Generated with VulnerableCode and provided on an 'AS IS' BASIS, WITHOUT WARRANTIES
#  OR CONDITIONS OF ANY KIND, either express or implied. No content created from
#  VulnerableCode should be considered or used as legal advice. Consult an Attorney
#  for any legal advice.
#  VulnerableCode is a free software code scanning tool from nexB Inc. and others.
#  Visit https://github.com/nexB/vulnerablecode/ for support and download.

from django.db import migrations
from django.db.models import Count
from django.db.models import Max


class Migration(migrations.Migration):

    dependencies = [
        ("vulnerabilities", "0013_auto_20220503_0941"),
    ]

    def remove_duplicate_rows(apps, schema_editor):
        """
        Find all duplicate rows and remove all of them except the latest one.
        """
        unique_fields = [
            "reference",
            "scoring_system",
            "value",
        ]
        Severities = apps.get_model("vulnerabilities", "VulnerabilitySeverity")
        # Get all duplicates according to the unique_fields
        duplicates = (
            Severities.objects.values(*unique_fields)
            .order_by()
            .annotate(max_id=Max("id"), count_id=Count("id"))
            .filter(count_id__gt=1)
        )
        for duplicate in duplicates:
            unique_fields_data = {
                uniqe_field: duplicate[uniqe_field] for uniqe_field in unique_fields
            }
            # Get all rows with the same unique_fields_data
            # exclude the latest one
            # and delete rest of them
            (
                Severities.objects.filter(**unique_fields_data)
                .exclude(id=duplicate["max_id"])
                .delete()
            )

    # sepecifying migrations.RunPython.noop as reverse_code
    operations = [migrations.RunPython(remove_duplicate_rows, migrations.RunPython.noop)]
